/*
  This file is part of SLS.
  Copyright (C) 2008 Sebastien LUTTRINGER <contact@seblu.net>

  SLS is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  SLS is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with SLS; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef SERVER_HH
# define SERVER_HH

# include "connection.hh"

# include <set>
# include <pthread.h>

class Server {
public:
  typedef std::set<string> Stringset;
  typedef std::set<pthread_t> Threadset;

  enum e_client {
    CLI_DAEMON,
    CLI_CONSOLE
  };

public:
  Server();
  ~Server();

  void start(int port, size_t max_conn, bool verbose = false);
  void stop();

  bool started();

  e_client login();

  static void *start_client(void *);

private:
  Stringset logged_hosts_;
  Stringset logged_users_;

  Threadset threads_;
  pthread_mutex_t threads_mutex_;

  Connection conn_;
  size_t max_conn_;
  bool verbose_;
};

void *start_client(void *fd);


#endif
